@@ -1,5 +1,5 @@
 import numpy as np
-from rotation2d import Rotation2D
+from .rotation2d import Rotation2D
 
 class Pose2D:
     def __init__(self, name) -> None:
