@@ -3,7 +3,7 @@ import numpy as np
 from scipy.spatial.transform import Rotation
 import logging as log
 
-from transform import Transform
+from .transform import Transform
 
 
 class TransformSet:
